Platforms
=========

.. automodule:: stonesoup.platform
    :no-members:

.. automodule:: stonesoup.platform.base
    :show-inheritance:

.. automodule:: stonesoup.platform.simple
    :show-inheritance:


